Changes
=======

0.5 (2023-07-29)
----------------

- Convert main navigation to hoverable sidebar.
- Add support for replacing attachments.
- Add icons to action buttons.
- Major code refactor.

0.4 (2023-07-19)
----------------

- Rewrite edit link on server to navigate to Tekir admin page.
- Add view button to contents page.
- Add support for opening relevant folders in file manager.
- Add support for adding attachments.
- Add support for publishing site to servers.
- Make UI language preference persistent.

0.3 (2023-07-17)
----------------

- Add support for adding content items.
- Add support for building and cleaning site.

0.2 (2023-07-12)
----------------

- Internationalize type names in edit forms.
- Properly handle adding/deleting/reordering flow blocks.
- Add support for deleting multiple selected content items.
- Add support for time widgets.
- Add dark-light mode toggle.

0.1 (2023-07-04)
----------------

- Initial release.
